ConstStr

Struct ConstStr 

pub struct ConstStr { /* private fields */ }
A string that is stored in a constant sized buffer that can be serialized and deserialized at compile time

Implementations

Source

impl ConstStr

pub const fn new(s: &str) -> Self

Create a new constant string

pub const fn as_str(&self) -> &str

Get a reference to the string

pub const fn len(&self) -> usize

Get the length of the string

pub const fn is_empty(&self) -> bool

Check if the string is empty

pub const fn push(self, byte: char) -> Self

Push a character onto the string

pub const fn push_str(self, str: &str) -> Self

Push a str onto the string

pub const fn split_at(self, index: usize) -> (Self, Self)

Split the string at a byte index. The byte index must be a char boundary

pub const fn rsplit_once(&self, char: char) -> Option<(Self, Self)>

Split the string at the last occurrence of a character

pub const fn split_once(&self, char: char) -> Option<(Self, Self)>

Split the string at the first occurrence of a character